summaryrefslogtreecommitdiffstats
path: root/jjb/fuel
diff options
context:
space:
mode:
authorTrevor Bramwell <tbramwell@linuxfoundation.org>2018-05-31 23:21:42 +0000
committerGerrit Code Review <gerrit@opnfv.org>2018-05-31 23:21:42 +0000
commitade23398c6b761e6f6a40568ee75ed5f241ad5f4 (patch)
tree1a43cc85f7b53c916b62879dcb16f3efd54ac93c /jjb/fuel
parent19d416ad450622cb6998680cf60ae1d7cf8e7929 (diff)
parent61211cbe691454e90f8a79583296b8039bad9baf (diff)
Merge "Auto: Setup Ci Jobs for Auto project"
Diffstat (limited to 'jjb/fuel')
-rwxr-xr-xjjb/fuel/fuel-deploy.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/jjb/fuel/fuel-deploy.sh b/jjb/fuel/fuel-deploy.sh
index 35bf3dc01..433061a96 100755
--- a/jjb/fuel/fuel-deploy.sh
+++ b/jjb/fuel/fuel-deploy.sh
@@ -55,8 +55,8 @@ if [ "${PROJECT}" = 'fuel' ]; then
fi
else
SUDO=
- # Armband currently supports arm, enea labs
- if [[ ! "${LAB_NAME}" =~ (arm|enea) ]]; then
+ # Armband currently supports arm, enea, unh labs
+ if [[ ! "${LAB_NAME}" =~ (arm|enea|unh) ]]; then
echo "Unsupported/unidentified lab ${LAB_NAME}. Cannot continue!"
exit 1
fi